# dbdbd -- David Black's DataBase Definer, version 0.2.2
#          Copyright (c) 2002, 2003 David Alan Black
#                              dblack@wobblini.net
#          See README for license information.

$:.unshift("..")
require '../dbdbd.rb'
require 'test/unit'

class TestMe < Test::Unit::TestCase

  def test_noend
    db = DBDB.new("%d%s%s")
    db.tie("raw/noend.txt")
    db.read
    db.sync
    s = `cat raw/noend.txt`
    t = `cat noend.txt`
    assert_equal(t,s)
  end

  def test_just_header
    db = DBDB.new("%d%s%s")
    db.tie("raw/just_header.txt")
    db.read
    db.sync
    s = `cat raw/just_header.txt`
    t = `cat just_header.txt`
    assert_equal(t,s)
  end
  def test_fixed
    db = DBDB.new("%21c%35c%12c")
    db.tie("fixed.txt")
    db.read
    db.tie("raw/fixed.txt")
    db.sync
    assert_equal(`cat fixed.txt`, `cat raw/fixed.txt`)
  end

  def test_manip
    File.open("output.txt","w") {}
    File.delete("output.txt")
    db = DBDB.new("%s%f%s")
    db.insert("hi", 1.2, "there")
    db.insert("tricky", 7.3e4, "number")
    db.insert("howdy", 34.5e6, "y'all")
    assert_equal(db["hi"], ["hi",1.2,"there"])
    assert_equal(db["hi"][1], 1.2)
    db.fields = %w{ str1 num str2}
    assert_equal(db["hi"]["str1"], "hi")
    db.tie("output.txt")
    db.sort_key = "str2"
    db.sync!
    db.read
    assert_equal(db["hi"]["str1"], "hi")
    db.clear
    db.uniq_key = 2
    db.read
    assert_equal(db[1.2], ["hi",1.2,"there"])
    db[1.2].comment = "Comment\nfor 1.2"
    db.header = "Top of the file\nComment"
    db.endmatter = "endstuff"
    puts
    puts "Now testing #dump (print database to STDOUT):"
    puts
    db.dump
    db.sort_key = 2
 end

  def test_noheader
    db = DBDB.new("%d%s%s")
    db.tie("raw/noheader.txt")
    db.read
    db.sync
    s = `cat raw/noheader.txt`
    t = `cat noheader.txt`
    assert_equal(t,s)
  end
#end
#class Nothing
  def test_sorted
    db = DBDB.new("%d%s%s")
    db.tie("raw/unsorted.txt")
    db.read
    db.sync
    s = `cat raw/unsorted.txt`
    t = `cat file.txt`
    assert_equal(t,s)
  end

  def test_fields
    db = DBDB.new("%d%s%s")
    db.tie("raw/fields.txt")
    db.read
    db.sync
    s = `cat raw/fields.txt`
    t = `cat fields.txt`
    assert_equal(t,s)
  end

  def test_noheader_yesfields
    db = DBDB.new("%d%s%s")
    db.tie("raw/noheaderf.txt")
    db.read
    db.sync
    s = `cat raw/noheaderf.txt`
    t = `cat noheaderf.txt`
    assert_equal(t,s)
  end
  
  def test_malformed
    db = DBDB.new("%d%s%s")
    db.tie("malformed.txt")
    puts
    puts "You should see three malformed warnings here:"
    puts
    db.read
    db.sync
  end
end
